==> aurelia-validation-0.10.0.jar: META-INF/resources/webjars/aurelia-validation/0.10.0/doc/CHANGELOG.md <==
<a name="0.10.0"></a>
# [0.10.0](https://github.com/aurelia/validation/compare/0.9.2...v0.10.0) (2016-06-22)


### Bug Fixes

* **validate-binding-behavior:** IE11 compat ([396e785](https://github.com/aurelia/validation/commit/396e785)), closes [#257](https://github.com/aurelia/validation/issues/257)



### 0.8.1 (2016-05-10)


#### Bug Fixes

* **package.json:** fix dependencies ([3415f243](https://github.com/aurelia/validation/commit/3415f243b158682bbcb0b45adaac2838a536fb33))


## 0.8.0 (2016-05-03)


#### Bug Fixes

* **package.json:** fix dependencies ([3415f243](https://github.com/aurelia/validation/commit/3415f243b158682bbcb0b45adaac2838a536fb33))


### 1.0.0-beta.1.0.0 (2016-01-29)


#### Features

* **all:** update jspm meta ([a2afb48e](http://github.com/aurelia/skeleton-plugin/commit/a2afb48e7cc83ab736b51ac2e4d5b7b3e3177ec2))


## 0.3.0 (2015-08-14)


#### Bug Fixes

* **index:** update to latest configuration api ([44f7a015](http://github.com/aurelia/skeleton-plugin/commit/44f7a015c0f15251bd07b327e42c875eaccbb735))


### 0.2.1 (2015-07-07)


## 0.2.0 (2015-06-08)


#### Bug Fixes

* **all:**
  * update to latest plugin api ([a050d736](http://github.com/aurelia/skeleton-plugin/commit/a050d736d32811066ffa902615cc73e1a5cbb6e3))
  * update compiler ([faf51acc](http://github.com/aurelia/skeleton-plugin/commit/faf51accc1514c6767eaed60df16dd3d586b5cc5))


#### Features

* **all:** initial commit of skeleton ([51a036d1](http://github.com/aurelia/skeleton-plugin/commit/51a036d146750a0bafd443dbc3def51ef7f89f6e))

==> aurelia-validation-0.11.0.jar: META-INF/resources/webjars/aurelia-validation/0.11.0/doc/CHANGELOG.md <==
<a name="0.11.0"></a>
# [0.11.0](https://github.com/aurelia/validation/compare/0.10.1...v0.11.0) (2016-07-27)



<a name="0.10.1"></a>
## [0.10.1](https://github.com/aurelia/validation/compare/0.10.0...v0.10.1) (2016-07-22)


### Bug Fixes

* **validation:** Add proper resources to package.json for webpack ([#268](https://github.com/aurelia/validation/issues/268)) ([dca4031](https://github.com/aurelia/validation/commit/dca4031))



<a name="0.10.0"></a>
# [0.10.0](https://github.com/aurelia/validation/compare/0.9.2...v0.10.0) (2016-06-22)


### Bug Fixes

* **validate-binding-behavior:** IE11 compat ([396e785](https://github.com/aurelia/validation/commit/396e785)), closes [#257](https://github.com/aurelia/validation/issues/257)



### 0.8.1 (2016-05-10)


#### Bug Fixes

* **package.json:** fix dependencies ([3415f243](https://github.com/aurelia/validation/commit/3415f243b158682bbcb0b45adaac2838a536fb33))


## 0.8.0 (2016-05-03)


#### Bug Fixes

* **package.json:** fix dependencies ([3415f243](https://github.com/aurelia/validation/commit/3415f243b158682bbcb0b45adaac2838a536fb33))


### 1.0.0-beta.1.0.0 (2016-01-29)


#### Features

* **all:** update jspm meta ([a2afb48e](http://github.com/aurelia/skeleton-plugin/commit/a2afb48e7cc83ab736b51ac2e4d5b7b3e3177ec2))


## 0.3.0 (2015-08-14)


#### Bug Fixes

* **index:** update to latest configuration api ([44f7a015](http://github.com/aurelia/skeleton-plugin/commit/44f7a015c0f15251bd07b327e42c875eaccbb735))


### 0.2.1 (2015-07-07)


## 0.2.0 (2015-06-08)


#### Bug Fixes

* **all:**
  * update to latest plugin api ([a050d736](http://github.com/aurelia/skeleton-plugin/commit/a050d736d32811066ffa902615cc73e1a5cbb6e3))
  * update compiler ([faf51acc](http://github.com/aurelia/skeleton-plugin/commit/faf51accc1514c6767eaed60df16dd3d586b5cc5))


#### Features

* **all:** initial commit of skeleton ([51a036d1](http://github.com/aurelia/skeleton-plugin/commit/51a036d146750a0bafd443dbc3def51ef7f89f6e))
